@@ -32,10 +32,7 @@
 	self = [super init];
 
 	@try {
-		if (red < 0.0 || red > 1.0 ||
-		    green < 0.0 || green > 1.0 ||
-		    blue < 0.0 || blue > 1.0 ||
-		    alpha < 0.0 || alpha > 1.0)
+		if (alpha < 0.0 || alpha > 1.0)
 			@throw [OFInvalidArgumentException exception];
 
 		_red = red;
@@ -43,7 +40,7 @@
 		_blue = blue;
 		_alpha = alpha;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -63,4 +60,3 @@
 		*alpha = _alpha;
 }
 @end
-
