@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -21,8 +21,9 @@
 
 OF_ASSUME_NONNULL_BEGIN
 
+OF_DIRECT_MEMBERS
 @interface OFFileIRIHandler: OFIRIHandler
-+ (bool)of_directoryExistsAtPath: (OFString *)path OF_DIRECT;
++ (bool)of_directoryExistsAtPath: (OFString *)path;
 @end
 
 OF_ASSUME_NONNULL_END
