@@ -139,8 +139,8 @@ OFLogV(OFConstantString *format, va_list arguments)
 	if (me == nil)
 		me = @"?";
 
-	msg = [[[OFString alloc] initWithFormat: format
-				      arguments: arguments] autorelease];
+	msg = objc_autorelease([[OFString alloc] initWithFormat: format
+						      arguments: arguments]);
 
 	[OFStdErr writeFormat: @"[%@.%03d %@(%d)] %@\n", dateString,
 			       date.microsecond / 1000, me, getpid(), msg];
@@ -419,6 +419,7 @@ colorTo256Color(uint8_t red, uint8_t green, uint8_t blue)
 	_handle = handle;
 	_closable = closable;
 	_colors = 16;
+	_cursorVisible = true;
 
 	return self;
 }
@@ -442,6 +443,7 @@ colorTo256Color(uint8_t red, uint8_t green, uint8_t blue)
 # else
 	_colors = -1;
 # endif
+	_cursorVisible = self.hasTerminal;
 
 	return self;
 }
@@ -659,8 +661,10 @@ colorTo256Color(uint8_t red, uint8_t green, uint8_t blue)
 
 - (bool)hasTerminal
 {
-#if defined(OF_WII) || defined(OF_NINTENDO_DS) || defined(OF_NINTENDO_3DS) || \
-    defined(OF_NINTENDO_SWITCH)
+#if defined(OF_AMIGAOS)
+	return IsInteractive(_handle);
+#elif defined(OF_WII) || defined(OF_NINTENDO_DS) || \
+    defined(OF_NINTENDO_3DS) || defined(OF_NINTENDO_SWITCH)
 	return true;
 #elif defined(HAVE_ISATTY) && !defined(OF_WII_U)
 	return isatty(_fd);
@@ -792,8 +796,8 @@ colorTo256Color(uint8_t red, uint8_t green, uint8_t blue)
 	}
 #endif
 
-	[_foregroundColor release];
-	_foregroundColor = [color retain];
+	objc_release(_foregroundColor);
+	_foregroundColor = objc_retain(color);
 }
 
 - (OFColor *)backgroundColor
@@ -840,8 +844,8 @@ colorTo256Color(uint8_t red, uint8_t green, uint8_t blue)
 	}
 #endif
 
-	[_backgroundColor release];
-	_backgroundColor = [color retain];
+	objc_release(_backgroundColor);
+	_backgroundColor = objc_retain(color);
 }
 
 - (bool)isBold
@@ -924,6 +928,28 @@ colorTo256Color(uint8_t red, uint8_t green, uint8_t blue)
 #endif
 }
 
+- (bool)isCursorVisible
+{
+	return _cursorVisible;
+}
+
+- (void)setCursorVisible: (bool)visible
+{
+	if (!self.hasTerminal)
+		return;
+
+	if (visible == _cursorVisible)
+		return;
+
+#ifdef OF_MSDOS
+	_setcursortype(visible ? _NORMALCURSOR : _NOCURSOR);
+#else
+	[self writeString: (visible ? @"\033[?25h" : @"\033[?25l")];
+#endif
+
+	_cursorVisible = visible;
+}
+
 - (void)reset
 {
 	if (!self.hasTerminal)
@@ -935,8 +961,8 @@ colorTo256Color(uint8_t red, uint8_t green, uint8_t blue)
 	[self writeString: @"\033[0m"];
 #endif
 
-	[_foregroundColor release];
-	[_backgroundColor release];
+	objc_release(_foregroundColor);
+	objc_release(_backgroundColor);
 	_foregroundColor = _backgroundColor = nil;
 	_bold = false;
 	_italic = false;
