@@ -143,7 +143,7 @@ extern bool _OFUnicodeToKOI8U(const OFUnichar *, unsigned char *,
     size_t, bool, bool);
 
 /* References for static linking */
-void OF_VISIBILITY_HIDDEN
+void OF_VISIBILITY_INTERNAL
 _references_to_categories_of_OFString(void)
 {
 	_OFString_CryptographicHashing_reference = 1;
@@ -157,7 +157,7 @@ _references_to_categories_of_OFString(void)
 	_OFString_XMLUnescaping_reference = 1;
 }
 
-void OF_VISIBILITY_HIDDEN
+void OF_VISIBILITY_INTERNAL
 _reference_to_OFConstantString(void)
 {
 	[OFConstantString class];
@@ -380,17 +380,11 @@ _OFStrDup(const char *string)
 static bool
 isASCIIWithoutNull(const char *string, size_t length)
 {
-	uint8_t combined = 0;
-	bool containsNull = false;
+	for (size_t i = 0; i < length; i++)
+		if ((unsigned char)string[i] >= 0x80 || string[i] == '\0')
+			return false;
 
-	for (size_t i = 0; i < length; i++) {
-		combined |= string[i];
-
-		if (string[i] == '\0')
-			containsNull = true;
-	}
-
-	return !(combined & ~0x7F) && !containsNull;
+	return true;
 }
 #endif
 
@@ -505,12 +499,14 @@ isASCIIWithoutNull(const char *string, size_t length)
 		}
 #endif
 
-		string = OFAllocObject([OFUTF8String class], length + 1, 1,
-		    &storage);
+		if (encoding == OFStringEncodingUTF8) {
+			string = OFAllocObject([OFUTF8String class],
+			    length + 1, 1, &storage);
 
-		return (id)[string of_initWithUTF8String: cString
-						  length: length
-						 storage: storage];
+			return (id)[string of_initWithUTF8String: cString
+							  length: length
+							 storage: storage];
+		}
 	}
 
 	return (id)[[OFUTF8String alloc] initWithCString: cString
@@ -541,12 +537,14 @@ isASCIIWithoutNull(const char *string, size_t length)
 		}
 #endif
 
-		string = OFAllocObject([OFUTF8String class], cStringLength + 1,
-		    1, &storage);
+		if (encoding == OFStringEncodingUTF8) {
+			string = OFAllocObject([OFUTF8String class],
+			    cStringLength + 1, 1, &storage);
 
-		return (id)[string of_initWithUTF8String: cString
-						  length: cStringLength
-						 storage: storage];
+			return (id)[string of_initWithUTF8String: cString
+							  length: cStringLength
+							 storage: storage];
+		}
 	}
 
 	return (id)[[OFUTF8String alloc] initWithCString: cString
@@ -734,129 +732,143 @@ OF_SINGLETON_METHODS
 
 + (instancetype)string
 {
-	return [[[self alloc] init] autorelease];
+	return objc_autoreleaseReturnValue([[self alloc] init]);
 }
 
 + (instancetype)stringWithUTF8String: (const char *)UTF8String
 {
-	return [[[self alloc] initWithUTF8String: UTF8String] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF8String: UTF8String]);
 }
 
 + (instancetype)stringWithUTF8String: (const char *)UTF8String
 			      length: (size_t)UTF8StringLength
 {
-	return [[[self alloc]
-	    initWithUTF8String: UTF8String
-			length: UTF8StringLength] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF8String: UTF8String
+				      length: UTF8StringLength]);
 }
 
 + (instancetype)stringWithUTF8StringNoCopy: (char *)UTF8String
 			      freeWhenDone: (bool)freeWhenDone
 {
-	return [[[self alloc]
-	    initWithUTF8StringNoCopy: UTF8String
-			freeWhenDone: freeWhenDone] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF8StringNoCopy: UTF8String
+				      freeWhenDone: freeWhenDone]);
 }
 
 + (instancetype)stringWithUTF8StringNoCopy: (char *)UTF8String
 				    length: (size_t)UTF8StringLength
 			      freeWhenDone: (bool)freeWhenDone
 {
-	return [[[self alloc]
-	    initWithUTF8StringNoCopy: UTF8String
-			      length: UTF8StringLength
-			freeWhenDone: freeWhenDone] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF8StringNoCopy: UTF8String
+					    length: UTF8StringLength
+				      freeWhenDone: freeWhenDone]);
 }
 
 + (instancetype)stringWithCString: (const char *)cString
 			 encoding: (OFStringEncoding)encoding
 {
-	return [[[self alloc] initWithCString: cString
-				     encoding: encoding] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithCString: cString
+				 encoding: encoding]);
 }
 
 + (instancetype)stringWithCString: (const char *)cString
 			 encoding: (OFStringEncoding)encoding
 			   length: (size_t)cStringLength
 {
-	return [[[self alloc] initWithCString: cString
-				     encoding: encoding
-				       length: cStringLength] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithCString: cString
+				 encoding: encoding
+				   length: cStringLength]);
 }
 
 + (instancetype)stringWithData: (OFData *)data
 		      encoding: (OFStringEncoding)encoding
 {
-	return [[[self alloc] initWithData: data
-				  encoding: encoding] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithData: data
+			      encoding: encoding]);
 }
 
 + (instancetype)stringWithString: (OFString *)string
 {
-	return [[[self alloc] initWithString: string] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithString: string]);
 }
 
 + (instancetype)stringWithCharacters: (const OFUnichar *)string
 			      length: (size_t)length
 {
-	return [[[self alloc] initWithCharacters: string
-					  length: length] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithCharacters: string
+				      length: length]);
 }
 
 + (instancetype)stringWithUTF16String: (const OFChar16 *)string
 {
-	return [[[self alloc] initWithUTF16String: string] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF16String: string]);
 }
 
 + (instancetype)stringWithUTF16String: (const OFChar16 *)string
 			       length: (size_t)length
 {
-	return [[[self alloc] initWithUTF16String: string
-					   length: length] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF16String: string
+				       length: length]);
 }
 
 + (instancetype)stringWithUTF16String: (const OFChar16 *)string
 			    byteOrder: (OFByteOrder)byteOrder
 {
-	return [[[self alloc] initWithUTF16String: string
-					byteOrder: byteOrder] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF16String: string
+				    byteOrder: byteOrder]);
 }
 
 + (instancetype)stringWithUTF16String: (const OFChar16 *)string
 			       length: (size_t)length
 			    byteOrder: (OFByteOrder)byteOrder
 {
-	return [[[self alloc] initWithUTF16String: string
-					   length: length
-					byteOrder: byteOrder] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF16String: string
+				       length: length
+				    byteOrder: byteOrder]);
 }
 
 + (instancetype)stringWithUTF32String: (const OFChar32 *)string
 {
-	return [[[self alloc] initWithUTF32String: string] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF32String: string]);
 }
 
 + (instancetype)stringWithUTF32String: (const OFChar32 *)string
 			       length: (size_t)length
 {
-	return [[[self alloc] initWithUTF32String: string
-					   length: length] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF32String: string
+				       length: length]);
 }
 
 + (instancetype)stringWithUTF32String: (const OFChar32 *)string
 			    byteOrder: (OFByteOrder)byteOrder
 {
-	return [[[self alloc] initWithUTF32String: string
-					byteOrder: byteOrder] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF32String: string
+				    byteOrder: byteOrder]);
 }
 
 + (instancetype)stringWithUTF32String: (const OFChar32 *)string
 			       length: (size_t)length
 			    byteOrder: (OFByteOrder)byteOrder
 {
-	return [[[self alloc] initWithUTF32String: string
-					   length: length
-					byteOrder: byteOrder] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithUTF32String: string
+				       length: length
+				    byteOrder: byteOrder]);
 }
 
 + (instancetype)stringWithFormat: (OFConstantString *)format, ...
@@ -865,37 +877,40 @@ OF_SINGLETON_METHODS
 	va_list arguments;
 
 	va_start(arguments, format);
-	ret = [[[self alloc] initWithFormat: format
-				  arguments: arguments] autorelease];
+	ret = [[self alloc] initWithFormat: format arguments: arguments];
 	va_end(arguments);
 
-	return ret;
+	return objc_autoreleaseReturnValue(ret);
 }
 
 #ifdef OF_HAVE_FILES
 + (instancetype)stringWithContentsOfFile: (OFString *)path
 {
-	return [[[self alloc] initWithContentsOfFile: path] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithContentsOfFile: path]);
 }
 
 + (instancetype)stringWithContentsOfFile: (OFString *)path
 				encoding: (OFStringEncoding)encoding
 {
-	return [[[self alloc] initWithContentsOfFile: path
-					    encoding: encoding] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithContentsOfFile: path
+					encoding: encoding]);
 }
 #endif
 
 + (instancetype)stringWithContentsOfIRI: (OFIRI *)IRI
 {
-	return [[[self alloc] initWithContentsOfIRI: IRI] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithContentsOfIRI: IRI]);
 }
 
 + (instancetype)stringWithContentsOfIRI: (OFIRI *)IRI
 			       encoding: (OFStringEncoding)encoding
 {
-	return [[[self alloc] initWithContentsOfIRI: IRI
-					   encoding: encoding] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithContentsOfIRI: IRI
+				       encoding: encoding]);
 }
 
 - (instancetype)init
@@ -905,7 +920,7 @@ OF_SINGLETON_METHODS
 		@try {
 			[self doesNotRecognizeSelector: _cmd];
 		} @catch (id e) {
-			[self release];
+			objc_release(self);
 			@throw e;
 		}
 
@@ -984,7 +999,7 @@ OF_SINGLETON_METHODS
 		if (data.itemSize != 1)
 			@throw [OFInvalidArgumentException exception];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -1136,7 +1151,7 @@ OF_SINGLETON_METHODS
 	@try {
 		IRI = [OFIRI fileIRIWithPath: path isDirectory: false];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -1163,7 +1178,7 @@ OF_SINGLETON_METHODS
 	@try {
 		data = [OFData dataWithContentsOfIRI: IRI];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -1678,7 +1693,7 @@ OF_SINGLETON_METHODS
 
 - (id)copy
 {
-	return [self retain];
+	return objc_retain(self);
 }
 
 - (id)mutableCopy
@@ -1811,7 +1826,7 @@ OF_SINGLETON_METHODS
 
 - (OFString *)description
 {
-	return [[self copy] autorelease];
+	return objc_autoreleaseReturnValue([self copy]);
 }
 
 - (OFString *)JSONRepresentation
@@ -1829,7 +1844,7 @@ OF_SINGLETON_METHODS
     of_JSONRepresentationWithOptions: (OFJSONRepresentationOptions)options
 			       depth: (size_t)depth
 {
-	OFMutableString *JSON = [[self mutableCopy] autorelease];
+	OFMutableString *JSON = objc_autorelease([self mutableCopy]);
 
 	/* FIXME: This is slow! Write it in pure C! */
 	[JSON replaceOccurrencesOfString: @"\\" withString: @"\\\\"];
@@ -2117,8 +2132,7 @@ OF_SINGLETON_METHODS
 	void *pool;
 	OFString *ret;
 
-	if (range.length > SIZE_MAX - range.location ||
-	    range.location + range.length > self.length)
+	if (OFEndOfRange(range) > self.length)
 		@throw [OFOutOfRangeException exception];
 
 	pool = objc_autoreleasePoolPush();
@@ -2127,7 +2141,7 @@ OF_SINGLETON_METHODS
 			length: range.length];
 	objc_autoreleasePoolPop(pool);
 
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 
 - (OFString *)stringByAppendingString: (OFString *)string
@@ -2166,7 +2180,7 @@ OF_SINGLETON_METHODS
 - (OFString *)stringByReplacingOccurrencesOfString: (OFString *)string
 					withString: (OFString *)replacement
 {
-	OFMutableString *new = [[self mutableCopy] autorelease];
+	OFMutableString *new = objc_autorelease([self mutableCopy]);
 	[new replaceOccurrencesOfString: string withString: replacement];
 	[new makeImmutable];
 	return new;
@@ -2177,7 +2191,7 @@ OF_SINGLETON_METHODS
 					   options: (int)options
 					     range: (OFRange)range
 {
-	OFMutableString *new = [[self mutableCopy] autorelease];
+	OFMutableString *new = objc_autorelease([self mutableCopy]);
 	[new replaceOccurrencesOfString: string
 			     withString: replacement
 				options: options
@@ -2188,7 +2202,7 @@ OF_SINGLETON_METHODS
 
 - (OFString *)uppercaseString
 {
-	OFMutableString *new = [[self mutableCopy] autorelease];
+	OFMutableString *new = objc_autorelease([self mutableCopy]);
 	[new uppercase];
 	[new makeImmutable];
 	return new;
@@ -2196,7 +2210,7 @@ OF_SINGLETON_METHODS
 
 - (OFString *)lowercaseString
 {
-	OFMutableString *new = [[self mutableCopy] autorelease];
+	OFMutableString *new = objc_autorelease([self mutableCopy]);
 	[new lowercase];
 	[new makeImmutable];
 	return new;
@@ -2204,7 +2218,7 @@ OF_SINGLETON_METHODS
 
 - (OFString *)capitalizedString
 {
-	OFMutableString *new = [[self mutableCopy] autorelease];
+	OFMutableString *new = objc_autorelease([self mutableCopy]);
 	[new capitalize];
 	[new makeImmutable];
 	return new;
@@ -2212,7 +2226,7 @@ OF_SINGLETON_METHODS
 
 - (OFString *)stringByDeletingLeadingWhitespaces
 {
-	OFMutableString *new = [[self mutableCopy] autorelease];
+	OFMutableString *new = objc_autorelease([self mutableCopy]);
 	[new deleteLeadingWhitespaces];
 	[new makeImmutable];
 	return new;
@@ -2220,7 +2234,7 @@ OF_SINGLETON_METHODS
 
 - (OFString *)stringByDeletingTrailingWhitespaces
 {
-	OFMutableString *new = [[self mutableCopy] autorelease];
+	OFMutableString *new = objc_autorelease([self mutableCopy]);
 	[new deleteTrailingWhitespaces];
 	[new makeImmutable];
 	return new;
@@ -2228,7 +2242,7 @@ OF_SINGLETON_METHODS
 
 - (OFString *)stringByDeletingEnclosingWhitespaces
 {
-	OFMutableString *new = [[self mutableCopy] autorelease];
+	OFMutableString *new = objc_autorelease([self mutableCopy]);
 	[new deleteEnclosingWhitespaces];
 	[new makeImmutable];
 	return new;
@@ -2322,7 +2336,7 @@ OF_SINGLETON_METHODS
 	delimiterCharacters = delimiter.characters;
 
 	if (delimiterLength > length) {
-		[array addObject: [[self copy] autorelease]];
+		[array addObject: objc_autorelease([self copy])];
 		[array makeImmutable];
 
 		objc_autoreleasePoolPop(pool);
@@ -2941,11 +2955,11 @@ unsignedLongLongValueWithBase(OFString *self, unsigned char base,
 	    [OFData dataWithItems: [self cStringWithEncoding: encoding]
 			    count: [self cStringLengthWithEncoding: encoding]];
 
-	[data retain];
+	objc_retain(data);
 
 	objc_autoreleasePoolPop(pool);
 
-	return [data autorelease];
+	return objc_autoreleaseReturnValue(data);
 }
 
 #ifdef OF_WINDOWS
