@@ -200,7 +200,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 		_s->cString = OFAllocZeroedMemory(1, 1);
 		_s->freeWhenDone = true;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -241,7 +241,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 
 		_s->containsNull = containsNull;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -423,7 +423,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 
 		_s->cString[_s->cStringLength] = 0;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -470,7 +470,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 		_s->containsNull = containsNull;
 		_s->freeWhenDone = freeWhenDone;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -513,7 +513,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 			_s->containsNull = containsNull;
 		}
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -560,7 +560,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 			/* We don't care, as we only tried to make it smaller */
 		}
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -648,7 +648,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 			/* We don't care, as we only tried to make it smaller */
 		}
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -718,7 +718,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 			/* We don't care, as we only tried to make it smaller */
 		}
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -765,7 +765,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 			OFFreeMemory(tmp);
 		}
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -1069,8 +1069,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 	void *pool = objc_autoreleasePoolPush();
 	const OFUnichar *characters = self.characters;
 
-	if (range.length > SIZE_MAX - range.location ||
-	    range.location + range.length > _s->length)
+	if (OFEndOfRange(range) > _s->length)
 		@throw [OFOutOfRangeException exception];
 
 	memcpy(buffer, characters + range.location,
@@ -1088,8 +1087,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 	size_t cStringLength = string.UTF8StringLength;
 	size_t rangeLocation, rangeLength;
 
-	if (range.length > SIZE_MAX - range.location ||
-	    range.location + range.length > _s->length)
+	if (OFEndOfRange(range) > _s->length)
 		@throw [OFOutOfRangeException exception];
 
 	if (_s->isUTF8) {
@@ -1162,7 +1160,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 - (OFString *)substringWithRange: (OFRange)range
 {
 	size_t start = range.location;
-	size_t end = range.location + range.length;
+	size_t end = OFEndOfRange(range);
 
 	if (range.length > SIZE_MAX - range.location || end > _s->length)
 		@throw [OFOutOfRangeException exception];
@@ -1225,7 +1223,7 @@ _OFUTF8StringIndexToPosition(const char *string, size_t idx, size_t length)
 	cStringLength = delimiter.UTF8StringLength;
 
 	if (cStringLength > _s->cStringLength) {
-		[array addObject: [[self copy] autorelease]];
+		[array addObject: objc_autorelease([self copy])];
 		objc_autoreleasePoolPop(pool);
 
 		return array;
