@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -25,7 +25,7 @@ int _NSDictionary_OFObject_reference;
 @implementation NSDictionary (OFObject)
 - (OFDictionary *)OFObject
 {
-	return [[[OFNSDictionary alloc]
-	    initWithNSDictionary: self] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[OFNSDictionary alloc] initWithNSDictionary: self]);
 }
 @end
