@@ -35,9 +35,9 @@
 			  target: (OFString *)target
 			   errNo: (int)errNo
 {
-	return [[[self alloc] initWithIRI: IRI
-				   target: target
-				    errNo: errNo] autorelease];
+	return objc_autoreleaseReturnValue([[self alloc] initWithIRI: IRI
+							      target: target
+							       errNo: errNo]);
 }
 
 - (instancetype)init
@@ -56,7 +56,7 @@
 		_target = [target copy];
 		_errNo = errNo;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -65,8 +65,8 @@
 
 - (void)dealloc
 {
-	[_IRI release];
-	[_target release];
+	objc_release(_IRI);
+	objc_release(_target);
 
 	[super dealloc];
 }
