@@ -29,14 +29,15 @@
 
 + (instancetype)exceptionWithLock: (id <OFLocking>)lock errNo: (int)errNo
 {
-	return [[[self alloc] initWithLock: lock errNo: errNo] autorelease];
+	return objc_autoreleaseReturnValue([[self alloc] initWithLock: lock
+								errNo: errNo]);
 }
 
 - (instancetype)initWithLock: (id <OFLocking>)lock errNo: (int)errNo
 {
 	self = [super init];
 
-	_lock = [lock retain];
+	_lock = objc_retain(lock);
 	_errNo = errNo;
 
 	return self;
@@ -44,7 +45,7 @@
 
 - (void)dealloc
 {
-	[_lock release];
+	objc_release(_lock);
 
 	[super dealloc];
 }
