@@ -23,7 +23,7 @@
 #import "OHN64Controller.h"
 #import "OHN64Controller+Private.h"
 #import "OFDictionary.h"
-#ifdef HAVE_GAMECONTROLLER_GAMECONTROLLER_H
+#ifdef OF_HAVE_GCF
 # import "OFString+NSObject.h"
 #endif
 #import "OHGameControllerButton.h"
@@ -39,13 +39,13 @@ static OFString *const buttonNames[] = {
 };
 static const size_t numButtons = sizeof(buttonNames) / sizeof(*buttonNames);
 
-#ifdef HAVE_GAMECONTROLLER_GAMECONTROLLER_H
+#ifdef OF_HAVE_GCF
 static OFDictionary<OFString *, NSString *> *buttonsMap;
 static OFDictionary<OFString *, NSString *> *directionalPadsMap;
 #endif
 
 @implementation OHExtendedN64Controller
-#ifdef HAVE_GAMECONTROLLER_GAMECONTROLLER_H
+#ifdef OF_HAVE_GCF
 + (void)initialize
 {
 	void *pool;
@@ -83,7 +83,7 @@ static OFDictionary<OFString *, NSString *> *directionalPadsMap;
 	@try {
 		void *pool = objc_autoreleasePoolPush();
 		OFMutableDictionary *buttons =
-		    [[_buttons mutableCopy] autorelease];
+		    objc_autorelease([_buttons mutableCopy]);
 
 		for (size_t i = 0; i < numButtons; i++) {
 			OHGameControllerButton *button = [OHGameControllerButton
@@ -92,12 +92,13 @@ static OFDictionary<OFString *, NSString *> *directionalPadsMap;
 			[buttons setObject: button forKey: buttonNames[i]];
 		}
 		[buttons makeImmutable];
-		[_buttons release];
+		objc_release(_buttons);
+		_buttons = nil;
 		_buttons = [buttons copy];
 
 		objc_autoreleasePoolPop(pool);
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -120,7 +121,7 @@ static OFDictionary<OFString *, NSString *> *directionalPadsMap;
 }
 #endif
 
-#ifdef HAVE_GAMECONTROLLER_GAMECONTROLLER_H
+#ifdef OF_HAVE_GCF
 - (OFDictionary<OFString *, NSString *> *)oh_buttonsMap
 {
 	return buttonsMap;
