@@ -119,7 +119,7 @@ static const size_t numButtons = sizeof(buttonNames) / sizeof(*buttonNames);
 
 		objc_autoreleasePoolPop(pool);
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -128,8 +128,8 @@ static const size_t numButtons = sizeof(buttonNames) / sizeof(*buttonNames);
 
 - (void)dealloc
 {
-	[_buttons release];
-	[_directionalPads release];
+	objc_release(_buttons);
+	objc_release(_directionalPads);
 
 	[super dealloc];
 }
