@@ -32,19 +32,19 @@ int _OFString_PathAdditions_reference;
 {
 	OFMutableString *ret = [OFMutableString string];
 	void *pool = objc_autoreleasePoolPush();
-	bool firstAfterDevice = true;
+	OFString *lastComponent = nil;
 
 	for (OFString *component in components) {
 		if (component.length == 0)
 			continue;
 
-		if (!firstAfterDevice)
+		if (lastComponent != nil && ![lastComponent hasSuffix: @"/"] &&
+		    ![lastComponent hasSuffix: @":"])
 			[ret appendString: @"/"];
 
 		[ret appendString: component];
 
-		if (![component hasSuffix: @":"])
-			firstAfterDevice = false;
+		lastComponent = component;
 	}
 
 	[ret makeImmutable];
@@ -110,9 +110,9 @@ int _OFString_PathAdditions_reference;
 	void *pool = objc_autoreleasePoolPush();
 	OFString *ret = self.pathComponents.lastObject;
 
-	[ret retain];
+	objc_retain(ret);
 	objc_autoreleasePoolPop(pool);
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 
 - (OFString *)pathExtension
@@ -131,9 +131,9 @@ int _OFString_PathAdditions_reference;
 
 	ret = [fileName substringFromIndex: pos + 1];
 
-	[ret retain];
+	objc_retain(ret);
 	objc_autoreleasePoolPop(pool);
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 
 - (OFString *)stringByDeletingLastPathComponent
@@ -149,9 +149,9 @@ int _OFString_PathAdditions_reference;
 
 	if (count < 2) {
 		if ([components.firstObject hasSuffix: @":"]) {
-			ret = [components.firstObject retain];
+			ret = objc_retain(components.firstObject);
 			objc_autoreleasePoolPop(pool);
-			return [ret autorelease];
+			return objc_autoreleaseReturnValue(ret);
 		}
 
 		objc_autoreleasePoolPop(pool);
@@ -162,9 +162,9 @@ int _OFString_PathAdditions_reference;
 	    OFMakeRange(0, components.count - 1)];
 	ret = [OFString pathWithComponents: components];
 
-	[ret retain];
+	objc_retain(ret);
 	objc_autoreleasePoolPop(pool);
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 
 - (OFString *)stringByDeletingPathExtension
@@ -175,17 +175,17 @@ int _OFString_PathAdditions_reference;
 	size_t pos;
 
 	if (self.length == 0)
-		return [[self copy] autorelease];
+		return objc_autoreleaseReturnValue([self copy]);
 
 	pool = objc_autoreleasePoolPush();
-	components = [[self.pathComponents mutableCopy] autorelease];
+	components = objc_autorelease([self.pathComponents mutableCopy]);
 	fileName = components.lastObject;
 
 	pos = [fileName rangeOfString: @"."
 			      options: OFStringSearchBackwards].location;
 	if (pos == OFNotFound || pos == 0) {
 		objc_autoreleasePoolPop(pool);
-		return [[self copy] autorelease];
+		return objc_autoreleaseReturnValue([self copy]);
 	}
 
 	fileName = [fileName substringToIndex: pos];
@@ -194,9 +194,9 @@ int _OFString_PathAdditions_reference;
 
 	ret = [OFString pathWithComponents: components];
 
-	[ret retain];
+	objc_retain(ret);
 	objc_autoreleasePoolPop(pool);
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 
 - (OFString *)stringByStandardizingPath
@@ -214,10 +214,10 @@ int _OFString_PathAdditions_reference;
 
 	if (components.count == 1) {
 		objc_autoreleasePoolPop(pool);
-		return [[self copy] autorelease];
+		return objc_autoreleaseReturnValue([self copy]);
 	}
 
-	array = [[components mutableCopy] autorelease];
+	array = objc_autorelease([components mutableCopy]);
 
 	while (!done) {
 		size_t length = array.count;
@@ -252,9 +252,9 @@ int _OFString_PathAdditions_reference;
 	if ([self hasSuffix: @"/"])
 		ret = [ret stringByAppendingString: @"/"];
 
-	[ret retain];
+	objc_retain(ret);
 	objc_autoreleasePoolPop(pool);
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 
 - (OFString *)stringByAppendingPathComponent: (OFString *)component
@@ -265,7 +265,7 @@ int _OFString_PathAdditions_reference;
 	if ([self hasSuffix: @"/"] || [self hasSuffix: @":"])
 		return [self stringByAppendingString: component];
 	else {
-		OFMutableString *ret = [[self mutableCopy] autorelease];
+		OFMutableString *ret = objc_autorelease([self mutableCopy]);
 
 		[ret appendString: @"/"];
 		[ret appendString: component];
@@ -284,15 +284,15 @@ int _OFString_PathAdditions_reference;
 		OFString *fileName, *ret;
 
 		components =
-		    [[self.pathComponents mutableCopy] autorelease];
+		    objc_autorelease([self.pathComponents mutableCopy]);
 		fileName = [components.lastObject
 		    stringByAppendingFormat: @".%@", extension];
 		[components replaceObjectAtIndex: components.count - 1
 				      withObject: fileName];
 
-		ret = [[OFString pathWithComponents: components] retain];
+		ret = objc_retain([OFString pathWithComponents: components]);
 		objc_autoreleasePoolPop(pool);
-		return [ret autorelease];
+		return objc_autoreleaseReturnValue(ret);
 	} else
 		return [self stringByAppendingFormat: @".%@", extension];
 }
@@ -338,8 +338,8 @@ int _OFString_PathAdditions_reference;
 	size_t count;
 
 	path = [path substringFromIndex: 1];
-	components = [[[path
-	    componentsSeparatedByString: @"/"] mutableCopy] autorelease];
+	components = objc_autorelease(
+	    [[path componentsSeparatedByString: @"/"] mutableCopy]);
 	count = components.count;
 
 	for (size_t i = 0; i < count; i++) {
