@@ -47,23 +47,26 @@ OF_DIRECT_MEMBERS
 @implementation OFSubprocess
 + (instancetype)subprocessWithProgram: (OFString *)program
 {
-	return [[[self alloc] initWithProgram: program] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithProgram: program]);
 }
 
 + (instancetype)subprocessWithProgram: (OFString *)program
 			    arguments: (OFArray *)arguments
 {
-	return [[[self alloc] initWithProgram: program
-				    arguments: arguments] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithProgram: program
+				arguments: arguments]);
 }
 
 + (instancetype)subprocessWithProgram: (OFString *)program
 			  programName: (OFString *)programName
 			    arguments: (OFArray *)arguments
 {
-	return [[[self alloc] initWithProgram: program
-				  programName: programName
-				    arguments: arguments] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithProgram: program
+			      programName: programName
+				arguments: arguments]);
 }
 
 + (instancetype)subprocessWithProgram: (OFString *)program
@@ -71,10 +74,11 @@ OF_DIRECT_MEMBERS
 			    arguments: (OFArray *)arguments
 			  environment: (OFDictionary *)environment
 {
-	return [[[self alloc] initWithProgram: program
-				  programName: programName
-				    arguments: arguments
-				  environment: environment] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithProgram: program
+			      programName: programName
+				arguments: arguments
+			      environment: environment]);
 }
 
 - (instancetype)init
@@ -166,7 +170,7 @@ OF_DIRECT_MEMBERS
 
 		for (OFString *argument in arguments) {
 			OFMutableString *tmp =
-			    [[argument mutableCopy] autorelease];
+			    objc_autorelease([argument mutableCopy]);
 			bool containsSpaces = [tmp containsString: @" "];
 
 			[argumentsString appendString: @" "];
@@ -241,7 +245,7 @@ OF_DIRECT_MEMBERS
 		CloseHandle(_readPipe[1]);
 		CloseHandle(_writePipe[0]);
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
