@@ -146,7 +146,7 @@ int _OFString_PathAdditions_reference;
 
 	objc_autoreleasePoolPop(pool);
 
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 
 - (OFString *)pathExtension
@@ -165,9 +165,9 @@ int _OFString_PathAdditions_reference;
 
 	ret = [fileName substringFromIndex: pos + 1];
 
-	[ret retain];
+	objc_retain(ret);
 	objc_autoreleasePoolPop(pool);
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 
 - (OFString *)stringByDeletingLastPathComponent
@@ -203,7 +203,7 @@ int _OFString_PathAdditions_reference;
 
 			objc_autoreleasePoolPop(pool);
 
-			return [ret autorelease];
+			return objc_autoreleaseReturnValue(ret);
 		}
 	}
 
@@ -220,17 +220,17 @@ int _OFString_PathAdditions_reference;
 	size_t pos;
 
 	if (self.length == 0)
-		return [[self copy] autorelease];
+		return objc_autoreleaseReturnValue([self copy]);
 
 	pool = objc_autoreleasePoolPush();
-	components = [[self.pathComponents mutableCopy] autorelease];
+	components = objc_autorelease([self.pathComponents mutableCopy]);
 	fileName = components.lastObject;
 
 	pos = [fileName rangeOfString: @"."
 			      options: OFStringSearchBackwards].location;
 	if (pos == OFNotFound || pos == 0) {
 		objc_autoreleasePoolPop(pool);
-		return [[self copy] autorelease];
+		return objc_autoreleaseReturnValue([self copy]);
 	}
 
 	fileName = [fileName substringToIndex: pos];
@@ -239,9 +239,9 @@ int _OFString_PathAdditions_reference;
 
 	ret = [OFString pathWithComponents: components];
 
-	[ret retain];
+	objc_retain(ret);
 	objc_autoreleasePoolPop(pool);
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 
 - (OFString *)stringByStandardizingPath
@@ -259,10 +259,10 @@ int _OFString_PathAdditions_reference;
 
 	if (components.count == 1) {
 		objc_autoreleasePoolPop(pool);
-		return [[self copy] autorelease];
+		return objc_autoreleaseReturnValue([self copy]);
 	}
 
-	array = [[components mutableCopy] autorelease];
+	array = objc_autorelease([components mutableCopy]);
 
 	while (!done) {
 		size_t length = array.count;
@@ -296,11 +296,11 @@ int _OFString_PathAdditions_reference;
 	if ([self hasSuffix: @"/"])
 		[array addObject: @""];
 
-	ret = [[array componentsJoinedByString: @"/"] retain];
+	ret = objc_retain([array componentsJoinedByString: @"/"]);
 
 	objc_autoreleasePoolPop(pool);
 
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 
 - (OFString *)stringByAppendingPathComponent: (OFString *)component
@@ -311,7 +311,7 @@ int _OFString_PathAdditions_reference;
 	if ([self hasSuffix: @"/"])
 		return [self stringByAppendingString: component];
 	else {
-		OFMutableString *ret = [[self mutableCopy] autorelease];
+		OFMutableString *ret = objc_autorelease([self mutableCopy]);
 
 		[ret appendString: @"/"];
 		[ret appendString: component];
@@ -329,16 +329,16 @@ int _OFString_PathAdditions_reference;
 		OFMutableArray *components;
 		OFString *fileName, *ret;
 
-		components =
-		    [[self.pathComponents mutableCopy] autorelease];
+		components = objc_autorelease(
+		    [self.pathComponents mutableCopy]);
 		fileName = [components.lastObject
 		    stringByAppendingFormat: @".%@", extension];
 		[components replaceObjectAtIndex: components.count - 1
 				      withObject: fileName];
 
-		ret = [[OFString pathWithComponents: components] retain];
+		ret = objc_retain([OFString pathWithComponents: components]);
 		objc_autoreleasePoolPop(pool);
-		return [ret autorelease];
+		return objc_autoreleaseReturnValue(ret);
 	} else
 		return [self stringByAppendingFormat: @".%@", extension];
 }
