@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -579,6 +579,10 @@ extern void objc_setEnumerationMutationHandler(
  * @brief Constructs an instance of the specified class in the specified array
  *	  of bytes.
  *
+ * @warning Instances created using this *cannot* use the runtime's reference
+ *	    counting and will result in a crash. Use @ref class_createInstance
+ *	    instead!
+ *
  * @param class_ The class of which to construct an instance
  * @param bytes An array of bytes of at least the length of the instance size.
  *		Must be properly aligned for the class.
@@ -595,6 +599,57 @@ extern id _Nullable objc_constructInstance(Class _Nullable class_,
  */
 extern void *_Nullable objc_destructInstance(id _Nullable object);
 
+/**
+ * @brief Creates a new instance of the specified class with the specified
+ *	  amount of extra space after the instance variables.
+ *
+ * @param class_ The class of which to create an instance
+ * @param extraBytes The amount of extra space after the instance variables
+ * @return The created instance
+ */
+extern id _Nullable class_createInstance(Class _Nullable class_,
+    size_t extraBytes);
+
+/**
+ * @brief Disposes of the specified object.
+ *
+ * This destructs the object and frees the memory.
+ *
+ * @param object The object to dispose of
+ * @return `nil`
+ */
+extern id _Nullable object_dispose(id _Nullable object);
+
+/**
+ * @brief Retains the specified object.
+ *
+ * This is only to be used to implement the `retain` method in a root class.
+ *
+ * @param object The object to retain
+ * @return The retained object
+ */
+extern id _Nonnull _objc_rootRetain(id _Nonnull object);
+
+/**
+ * @brief Returns the retain count for the specified object.
+ *
+ * This is only to be used to implement the `retainCount` method in a root
+ * class.
+ *
+ * @param object The object whose retain count to return
+ * @return The retain count of the specified object
+ */
+extern unsigned int _objc_rootRetainCount(id _Nonnull object);
+
+/**
+ * @brief Releases the specified object.
+ *
+ * This is only to be used to implement the `release` method in a root class.
+ *
+ * @param object The object to release
+ */
+extern void _objc_rootRelease(id _Nonnull object);
+
 /**
  * @brief Creates a new autorelease pool and puts it on top of the stack of
  *	  autorelease pools.
@@ -702,8 +757,10 @@ extern void objc_removeAssociatedObjects(id _Nonnull object);
  * These declarations are also required to prevent Clang's implicit
  * declarations which include __declspec(dllimport) on Windows.
  */
-struct _objc_module;
-extern void __objc_exec_class(struct _objc_module *_Nonnull module);
+#ifdef __clang__
+struct objc_module;
+extern void __objc_exec_class(struct objc_module *_Nonnull module);
+#endif
 extern IMP _Nonnull objc_msg_lookup(id _Nullable object, SEL _Nonnull selector);
 extern IMP _Nonnull objc_msg_lookup_stret(id _Nullable object,
     SEL _Nonnull selector);
