@@ -49,7 +49,7 @@ objc_enumerationMutation(id object)
 	if (enumerationMutationHandler != NULL)
 		enumerationMutationHandler(object);
 	else
-		OBJC_ERROR("Object was mutated during enumeration!");
+		_OBJC_ERROR("Object was mutated during enumeration!");
 }
 
 void
@@ -59,7 +59,7 @@ objc_setEnumerationMutationHandler(objc_enumeration_mutation_handler handler)
 }
 
 void
-objc_error(const char *title, const char *format, ...)
+_objc_error(const char *title, const char *format, ...)
 {
 #if defined(OF_WINDOWS) || defined(OF_AMIGAOS)
 # define messageLen 512
@@ -82,7 +82,7 @@ objc_error(const char *title, const char *format, ...)
 	MessageBoxA(NULL, message, title,
 	    MB_OK | MB_SYSTEMMODAL | MB_ICONERROR);
 
-	exit(EXIT_FAILURE);
+	abort();
 #elif defined(OF_AMIGAOS)
 	struct Library *IntuitionBase;
 # ifdef OF_AMIGAOS4
@@ -90,17 +90,15 @@ objc_error(const char *title, const char *format, ...)
 # endif
 	struct EasyStruct easy;
 
-# ifndef OF_AMIGAOS4
 	kprintf("[%s] %s\n", title, message);
-# endif
 
 	if ((IntuitionBase = OpenLibrary("intuition.library", 0)) == NULL)
-		exit(EXIT_FAILURE);
+		abort();
 
 # ifdef OF_AMIGAOS4
 	if ((IIntuition = (struct IntuitionIFace *)GetInterface(IntuitionBase,
 	    "main", 1, NULL)) == NULL)
-		exit(EXIT_FAILURE);
+		abort();
 # endif
 
 	easy.es_StructSize = sizeof(easy);
@@ -117,7 +115,7 @@ objc_error(const char *title, const char *format, ...)
 
 	CloseLibrary(IntuitionBase);
 
-	exit(EXIT_FAILURE);
+	abort();
 #else
 	va_list args;
 
@@ -137,7 +135,7 @@ objc_error(const char *title, const char *format, ...)
 }
 
 char *
-objc_strdup(const char *string)
+_objc_strdup(const char *string)
 {
 	char *copy;
 	size_t length = strlen(string);
