@@ -71,10 +71,10 @@ class_conformsToProtocol(Class class, Protocol *protocol)
 			    protocol))
 				return true;
 
-	objc_globalMutex_lock();
+	_objc_globalMutex_lock();
 
-	if ((categories = objc_categoriesForClass(class)) == NULL) {
-		objc_globalMutex_unlock();
+	if ((categories = _objc_categoriesForClass(class)) == NULL) {
+		_objc_globalMutex_unlock();
 		return false;
 	}
 
@@ -85,14 +85,14 @@ class_conformsToProtocol(Class class, Protocol *protocol)
 			for (long j = 0; j < protocolList->count; j++) {
 				if (protocol_conformsToProtocol(
 				    protocolList->list[j], protocol)) {
-					objc_globalMutex_unlock();
+					_objc_globalMutex_unlock();
 					return true;
 				}
 			}
 		}
 	}
 
-	objc_globalMutex_unlock();
+	_objc_globalMutex_unlock();
 
 	return false;
 }
