@@ -28,14 +28,17 @@
 extern "C" {
 #endif
 extern const OFUnichar *const _Nonnull
-    _OFUnicodeUppercaseTable[_OFUnicodeUppercaseTableSize] OF_VISIBILITY_HIDDEN;
+    _OFUnicodeUppercaseTable[_OFUnicodeUppercaseTableSize]
+    OF_VISIBILITY_INTERNAL;
 extern const OFUnichar *const _Nonnull
-    _OFUnicodeLowercaseTable[_OFUnicodeLowercaseTableSize] OF_VISIBILITY_HIDDEN;
+    _OFUnicodeLowercaseTable[_OFUnicodeLowercaseTableSize]
+    OF_VISIBILITY_INTERNAL;
 extern const OFUnichar *const _Nonnull
-    _OFUnicodeTitlecaseTable[_OFUnicodeTitlecaseTableSize] OF_VISIBILITY_HIDDEN;
+    _OFUnicodeTitlecaseTable[_OFUnicodeTitlecaseTableSize]
+    OF_VISIBILITY_INTERNAL;
 extern const OFUnichar *const _Nonnull
     _OFUnicodeCaseFoldingTable[_OFUnicodeCaseFoldingTableSize]
-    OF_VISIBILITY_HIDDEN;
+    OF_VISIBILITY_INTERNAL;
 #ifdef __cplusplus
 }
 #endif
