@@ -78,7 +78,7 @@ static const OFUnichar uppercasePage1[0x100] = {
 	579, 0, 0, 386, 0, 388, 0, 0,
 	391, 0, 0, 0, 395, 0, 0, 0,
 	0, 0, 401, 0, 0, 502, 0, 0,
-	0, 408, 573, 0, 0, 0, 544, 0,
+	0, 408, 573, 42972, 0, 0, 544, 0,
 	0, 416, 0, 418, 0, 420, 0, 0,
 	423, 0, 0, 0, 0, 428, 0, 0,
 	431, 0, 0, 0, 435, 0, 437, 0,
@@ -106,7 +106,7 @@ static const OFUnichar uppercasePage2[0x100] = {
 	0, 584, 0, 586, 0, 588, 0, 590,
 	11375, 11373, 11376, 385, 390, 0, 393, 394,
 	0, 399, 0, 400, 42923, 0, 0, 0,
-	403, 42924, 0, 404, 0, 42893, 42922, 0,
+	403, 42924, 0, 404, 42955, 42893, 42922, 0,
 	407, 406, 42926, 11362, 42925, 0, 0, 412,
 	0, 11374, 413, 0, 0, 415, 0, 0,
 	0, 0, 0, 0, 0, 11364, 0, 0,
@@ -321,7 +321,7 @@ static const OFUnichar uppercasePage28[0x100] = {
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
 	1042, 1044, 1054, 1057, 1058, 1058, 1066, 1122,
-	42570, 0, 0, 0, 0, 0, 0, 0,
+	42570, 0, 7305, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
@@ -644,9 +644,9 @@ static const OFUnichar uppercasePage167[0x100] = {
 	0, 0, 0, 0, 0, 42932, 0, 42934,
 	0, 42936, 0, 42938, 0, 42940, 0, 42942,
 	0, 42944, 0, 42946, 0, 0, 0, 0,
-	42951, 0, 42953, 0, 0, 0, 0, 0,
+	42951, 0, 42953, 0, 0, 42956, 0, 0,
 	0, 42960, 0, 0, 0, 0, 0, 42966,
-	0, 42968, 0, 0, 0, 0, 0, 0,
+	0, 42968, 0, 42970, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 42997, 0,
@@ -828,6 +828,41 @@ static const OFUnichar uppercasePage268[0x100] = {
 	0, 0, 0, 0, 0, 0, 0, 0,
 };
 
+static const OFUnichar uppercasePage269[0x100] = {
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	68944, 68945, 68946, 68947, 68948, 68949, 68950, 68951,
+	68952, 68953, 68954, 68955, 68956, 68957, 68958, 68959,
+	68960, 68961, 68962, 68963, 68964, 68965, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+};
+
 static const OFUnichar uppercasePage280[0x100] = {
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
@@ -1231,7 +1266,7 @@ static const OFUnichar lowercasePage28[0x100] = {
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
-	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 7306, 0, 0, 0, 0, 0, 0,
 	4304, 4305, 4306, 4307, 4308, 4309, 4310, 4311,
 	4312, 4313, 4314, 4315, 4316, 4317, 4318, 4319,
 	4320, 4321, 4322, 4323, 4324, 4325, 4326, 4327,
@@ -1484,9 +1519,9 @@ static const OFUnichar lowercasePage167[0x100] = {
 	670, 647, 669, 43859, 42933, 0, 42935, 0,
 	42937, 0, 42939, 0, 42941, 0, 42943, 0,
 	42945, 0, 42947, 0, 42900, 642, 7566, 42952,
-	0, 42954, 0, 0, 0, 0, 0, 0,
+	0, 42954, 0, 612, 42957, 0, 0, 0,
 	42961, 0, 0, 0, 0, 0, 42967, 0,
-	42969, 0, 0, 0, 0, 0, 0, 0,
+	42969, 0, 42971, 0, 411, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 42998, 0, 0,
@@ -1633,6 +1668,41 @@ static const OFUnichar lowercasePage268[0x100] = {
 	0, 0, 0, 0, 0, 0, 0, 0,
 };
 
+static const OFUnichar lowercasePage269[0x100] = {
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	68976, 68977, 68978, 68979, 68980, 68981, 68982, 68983,
+	68984, 68985, 68986, 68987, 68988, 68989, 68990, 68991,
+	68992, 68993, 68994, 68995, 68996, 68997, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0,
+};
+
 static const OFUnichar lowercasePage280[0x100] = {
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
@@ -1758,7 +1828,7 @@ static const OFUnichar titlecasePage1[0x100] = {
 	579, 0, 0, 386, 0, 388, 0, 0,
 	391, 0, 0, 0, 395, 0, 0, 0,
 	0, 0, 401, 0, 0, 502, 0, 0,
-	0, 408, 573, 0, 0, 0, 544, 0,
+	0, 408, 573, 42972, 0, 0, 544, 0,
 	0, 416, 0, 418, 0, 420, 0, 0,
 	423, 0, 0, 0, 0, 428, 0, 0,
 	431, 0, 0, 0, 435, 0, 437, 0,
@@ -1966,7 +2036,7 @@ static const OFUnichar caseFoldingPage28[0x100] = {
 	0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0,
 	1074, 1076, 1086, 1089, 1090, 1090, 1098, 1123,
-	42571, 0, 0, 0, 0, 0, 0, 0,
+	42571, 7306, 0, 0, 0, 0, 0, 0,
 	4304, 4305, 4306, 4307, 4308, 4309, 4310, 4311,
 	4312, 4313, 4314, 4315, 4316, 4317, 4318, 4319,
 	4320, 4321, 4322, 4323, 4324, 4325, 4326, 4327,
@@ -2191,7 +2261,7 @@ const OFUnichar *const _OFUnicodeUppercaseTable[0x1EA] = {
 	emptyPage, emptyPage, emptyPage, emptyPage,
 	uppercasePage260, uppercasePage261, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage, emptyPage,
-	uppercasePage268, emptyPage, emptyPage, emptyPage,
+	uppercasePage268, uppercasePage269, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage, emptyPage,
 	uppercasePage280, emptyPage, emptyPage, emptyPage,
@@ -2317,7 +2387,7 @@ const OFUnichar *const _OFUnicodeLowercaseTable[0x1EA] = {
 	emptyPage, emptyPage, emptyPage, emptyPage,
 	lowercasePage260, lowercasePage261, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage, emptyPage,
-	lowercasePage268, emptyPage, emptyPage, emptyPage,
+	lowercasePage268, lowercasePage269, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage, emptyPage,
 	lowercasePage280, emptyPage, emptyPage, emptyPage,
@@ -2443,7 +2513,7 @@ const OFUnichar *const _OFUnicodeTitlecaseTable[0x1EA] = {
 	emptyPage, emptyPage, emptyPage, emptyPage,
 	uppercasePage260, uppercasePage261, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage, emptyPage,
-	uppercasePage268, emptyPage, emptyPage, emptyPage,
+	uppercasePage268, uppercasePage269, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage, emptyPage,
 	uppercasePage280, emptyPage, emptyPage, emptyPage,
@@ -2591,7 +2661,7 @@ const OFUnichar *const _OFUnicodeCaseFoldingTable[0x1EA] = {
 	emptyPage, emptyPage, lowercasePage260,
 	lowercasePage261, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage,
-	emptyPage, lowercasePage268, emptyPage,
+	emptyPage, lowercasePage268, lowercasePage269,
 	emptyPage, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage,
 	emptyPage, emptyPage, emptyPage,
