@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -41,7 +41,7 @@
 
 - (void)dealloc
 {
-	[_color release];
+	objc_release(_color);
 
 	[super dealloc];
 }
