@@ -26,6 +26,13 @@
 #import "OFStdIOStream.h"
 #import "OFString.h"
 
+#ifdef OF_AMIGAOS
+const char *VER = "$VER: objfw-new "
+    OF_PREPROCESSOR_STRINGIFY(OBJFW_VERSION_MAJOR) "."
+    OF_PREPROCESSOR_STRINGIFY(OBJFW_VERSION_MINOR) " (" BUILD_DATE ") "
+    "\xA9 2008-2025 Jonathan Schleifer";
+#endif
+
 @interface ObjFWNew: OFObject <OFApplicationDelegate>
 @end
 
