@@ -99,10 +99,11 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 			  mode: (OFString *)mode
 		      encoding: (OFStringEncoding)encoding
 {
-	return [[[self alloc] initWithIRI: IRI
-				   stream: stream
-				     mode: mode
-				 encoding: encoding] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithIRI: IRI
+			       stream: stream
+				 mode: mode
+			     encoding: encoding]);
 }
 
 - (instancetype)initWithIRI: (OFIRI *)IRI
@@ -118,7 +119,7 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 							   mode: mode];
 		_archive.delegate = self;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -127,8 +128,8 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 
 - (void)dealloc
 {
-	[_archiveIRI release];
-	[_archive release];
+	objc_release(_archiveIRI);
+	objc_release(_archive);
 
 	[super dealloc];
 }
@@ -149,7 +150,8 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 	if (partNumber == lastPartNumber)
 		IRI = _archiveIRI;
 	else {
-		OFMutableIRI *copy = [[_archiveIRI mutableCopy] autorelease];
+		OFMutableIRI *copy =
+		    objc_autorelease([_archiveIRI mutableCopy]);
 		[copy deletePathExtension];
 		[copy appendPathExtension: [OFString
 		    stringWithFormat: @"z%02u", partNumber + 1]];
@@ -176,6 +178,8 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 	for (OFZIPArchiveEntry *entry in _archive.entries) {
 		void *pool = objc_autoreleasePoolPush();
 
+		[app checkForCancellation];
+
 		[OFStdOut writeLine: entry.fileName];
 
 		if (app->_outputLevel >= 1) {
@@ -313,6 +317,8 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 		unsigned long long written = 0, size = entry.uncompressedSize;
 		int8_t percent = -1, newPercent;
 
+		[app checkForCancellation];
+
 		if (!all && ![files containsObject: fileName])
 			continue;
 
@@ -330,7 +336,7 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 		}
 
 		if (app->_outputLevel >= 0)
-			[OFStdOut writeString: OF_LOCALIZED(@"extracting_file",
+			[OFStdErr writeString: OF_LOCALIZED(@"extracting_file",
 			    @"Extracting %[file]...",
 			    @"file", fileName)];
 
@@ -348,8 +354,8 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 					   secondObject: entry]];
 
 			if (app->_outputLevel >= 0) {
-				[OFStdOut writeString: @"\r"];
-				[OFStdOut writeLine: OF_LOCALIZED(
+				[OFStdErr writeString: @"\r"];
+				[OFStdErr writeLine: OF_LOCALIZED(
 				    @"extracting_file_done",
 				    @"Extracting %[file]... done",
 				    @"file", fileName)];
@@ -371,9 +377,13 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 		setPermissions(outFileName, entry);
 
 		while (!stream.atEndOfStream) {
-			ssize_t length = [app copyBlockFromStream: stream
-							 toStream: output
-							 fileName: fileName];
+			ssize_t length;
+
+			[app checkForCancellation];
+
+			length = [app copyBlockFromStream: stream
+						 toStream: output
+						 fileName: fileName];
 
 			if (length < 0) {
 				app->_exitStatus = 1;
@@ -391,8 +401,8 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 				percentString = [OFString stringWithFormat:
 				    @"%3u", percent];
 
-				[OFStdOut writeString: @"\r"];
-				[OFStdOut writeString: OF_LOCALIZED(
+				[OFStdErr writeString: @"\r"];
+				[OFStdErr writeString: OF_LOCALIZED(
 				    @"extracting_file_percent",
 				    @"Extracting %[file]... %[percent]%",
 				    @"file", fileName,
@@ -404,8 +414,8 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 		setModificationDate(outFileName, entry);
 
 		if (app->_outputLevel >= 0) {
-			[OFStdOut writeString: @"\r"];
-			[OFStdOut writeLine: OF_LOCALIZED(
+			[OFStdErr writeString: @"\r"];
+			[OFStdErr writeLine: OF_LOCALIZED(
 			    @"extracting_file_done",
 			    @"Extracting %[file]... done",
 			    @"file", fileName)];
@@ -457,9 +467,13 @@ outer_loop_end:
 		}
 
 		while (!stream.atEndOfStream) {
-			ssize_t length = [app copyBlockFromStream: stream
-							 toStream: OFStdOut
-							 fileName: path];
+			ssize_t length;
+
+			[app checkForCancellation];
+
+			length = [app copyBlockFromStream: stream
+						 toStream: OFStdOut
+						 fileName: path];
 
 			if (length < 0) {
 				app->_exitStatus = 1;
@@ -488,6 +502,8 @@ outer_loop_end:
 		unsigned long long size;
 		OFStream *output;
 
+		[app checkForCancellation];
+
 		components = localFileName.pathComponents;
 		fileName = [components componentsJoinedByString: @"/"];
 
@@ -500,7 +516,7 @@ outer_loop_end:
 		}
 
 		if (app->_outputLevel >= 0)
-			[OFStdOut writeString: OF_LOCALIZED(@"adding_file",
+			[OFStdErr writeString: OF_LOCALIZED(@"adding_file",
 			    @"Adding %[file]...",
 			    @"file", fileName)];
 
@@ -526,10 +542,13 @@ outer_loop_end:
 							mode: @"r"];
 
 			while (!input.atEndOfStream) {
-				ssize_t length = [app
-				    copyBlockFromStream: input
-					       toStream: output
-					       fileName: fileName];
+				ssize_t length;
+
+				[app checkForCancellation];
+
+				length = [app copyBlockFromStream: input
+							 toStream: output
+							 fileName: fileName];
 
 				if (length < 0) {
 					app->_exitStatus = 1;
@@ -548,8 +567,8 @@ outer_loop_end:
 					percentString = [OFString
 					    stringWithFormat: @"%3u", percent];
 
-					[OFStdOut writeString: @"\r"];
-					[OFStdOut writeString: OF_LOCALIZED(
+					[OFStdErr writeString: @"\r"];
+					[OFStdErr writeString: OF_LOCALIZED(
 					    @"adding_file_percent",
 					    @"Adding %[file]... %[percent]%",
 					    @"file", fileName,
@@ -559,8 +578,8 @@ outer_loop_end:
 		}
 
 		if (app->_outputLevel >= 0) {
-			[OFStdOut writeString: @"\r"];
-			[OFStdOut writeLine: OF_LOCALIZED(
+			[OFStdErr writeString: @"\r"];
+			[OFStdErr writeLine: OF_LOCALIZED(
 			    @"adding_file_done",
 			    @"Adding %[file]... done",
 			    @"file", fileName)];
